@@ -132,12 +132,6 @@ class ExcelError(Exception):
 class Workbook(object):
     """Opens a connection to a Microsoft Excel application.
 
-    Attributes:
-        save_on_close: bool, if True, the open workbook will be automatically saved (if possible) when it is closed.
-        quit_on_close: bool, if True, the application will be quit when a workbook is closed.
-        app: win32com.client.dynamic.CDispatch, the connected Microsoft Excel application.
-        workbook: win32com.client.dynamic.CDispatch, the open Excel workbook.
-
     Arguments:
         filepath: The path to a file to open with Microsoft Excel.
         visible: bool, if False the application will not appear as a visible window.
@@ -149,6 +143,12 @@ class Workbook(object):
             not password-protected.
         write_reserved_password: str or None, the password required to write changes to the file defined by filepath.
             Not necessary if the file is not password-protected or you do not intend to write to the file.
+
+    Attributes:
+        save_on_close: bool, if True, the open workbook will be automatically saved (if possible) when it is closed.
+        quit_on_close: bool, if True, the application will be quit when a workbook is closed.
+        app: win32com.client.dynamic.CDispatch, the connected Microsoft Excel application.
+        workbook: win32com.client.dynamic.CDispatch, the open Excel workbook.
     """
     def __init__(self, filepath:str=None, visible:bool=False, save_on_close:bool=False, quit_on_close:bool=False,
                  display_alerts:bool=False, password:str or None=None, write_reserved_password:str or None=None):
@@ -526,6 +526,7 @@ class Range(object):
         Arguments:
             text: str, the comment to add.
         """
+        ## TODO: allow for multiple comments on a single cell (check first that this is possible in Excel)
         self.clear('comments')
         if text is not None:
             self._range.Cells(1).AddComment(text)
@@ -550,7 +551,9 @@ class Range(object):
                 the remaining cells will be left blank.
         """
         if isinstance(values, pd.core.frame.DataFrame):
+            cols = tuple(col for col in values.columns)
             values = tuple(map(tuple, values.values))
+            values = (cols,) + values
         values = format_values(values, self.rows, self.columns)
         self._range.Value2 = values
 
